blurred_overlay library

A Flutter package to show blurred dialogs, bottom sheets, drawers, and loading overlays using BackdropFilter with optional shadow, rounded corners, and safe area handling.

Classes

BlurredDrawer
A drawer widget with a blurred background effect.
BlurredLoadingOverlay
A widget that displays a blurred loading overlay on top of its child.
BlurredLoadingPercentage
A widget that displays a blurred loading overlay with progress percentage.

Enums

DrawerPosition
Position of the drawer (left or right side of the screen)
LoadingStyle
The style of loading animation to display.
ProgressStyle
The style of progress indicator to display.

Functions

showBlurredDialog<T>({required BuildContext context, required WidgetBuilder builder, double blurSigma = 4.0, bool barrierDismissible = true, Color barrierColor = Colors.transparent}) Future<T?>
Shows a blurred dialog with optional custom background and blur settings.
showBlurredModalBottomSheet<T>({required BuildContext context, required WidgetBuilder builder, double blurSigma = 4.0, bool isDismissible = true, bool enableDrag = true, bool useSafeArea = true, BorderRadius? borderRadius, double? minHeight, double? maxHeight, EdgeInsetsGeometry? margin, EdgeInsetsGeometry? padding, Color? backgroundColor, Color? barrierColor, bool showHandle = false, EdgeInsetsGeometry? handleMargin, BorderRadiusGeometry? handleRadius, Color? handleColor, double? handleHeight, double? handleWidth, ShapeBorder? shape, String? barrierLabel, bool useRootNavigator = false, BoxConstraints? constraints, Clip? clipBehavior, RouteSettings? routeSettings, AnimationStyle? sheetAnimationStyle, AnimationController? transitionAnimationController, Offset? anchorPoint, bool requestFocus = true}) Future<T?>
Shows a modal bottom sheet with a blurred background and customizable UI.