customLoadingWidget property
A custom widget to display as the loading indicator.
When provided, this overrides loadingStyle, loadingColor, and loadingSize.
Implementation
final Widget? customLoadingWidget;
A custom widget to display as the loading indicator.
When provided, this overrides loadingStyle, loadingColor, and loadingSize.
final Widget? customLoadingWidget;