LoadingStyle enum

The style of loading animation to display.

Inheritance
Available extensions

Values

bouncingLineCircle → const LoadingStyle

Three circles bouncing smoothly with sine wave motion.

bouncingLineSquare → const LoadingStyle

Three squares bouncing smoothly with sine wave motion.

bouncingGridCircle → const LoadingStyle

3x3 grid of circles with diagonal bounce effect.

bouncingGridSquare → const LoadingStyle

3x3 grid of squares with diagonal bounce effect.

bumpingLineCircle → const LoadingStyle

Three circles with horizontal bump motion.

bumpingLineSquare → const LoadingStyle

Three squares with horizontal bump motion.

fadingLineCircle → const LoadingStyle

Three circles with sequential fade effect.

fadingLineSquare → const LoadingStyle

Three squares with sequential fade effect.

jumpingLineCircle → const LoadingStyle

Three circles jumping vertically.

jumpingLineSquare → const LoadingStyle

Three squares jumping vertically.

rotatingSquare → const LoadingStyle

Single square rotating 360 degrees.

flippingCircle → const LoadingStyle

Single circle flipping horizontally 3 times.

flippingSquare → const LoadingStyle

Single square flipping horizontally 3 times.

doubleFlippingCircle → const LoadingStyle

Circle flipping on X then Y axis with 3D effect.

doubleFlippingSquare → const LoadingStyle

Square flipping on X then Y axis with 3D effect.

fillingSquare → const LoadingStyle

Square that fills and rotates while unfilling.

cupertinoBox → const LoadingStyle

iOS-style spinner in a semi-transparent rounded box. Takes 50% of screen width as a square container.

pulseRing → const LoadingStyle

Concentric rings expanding outward with fading opacity. Creates a radar/ripple-like effect.

orbitDots → const LoadingStyle

Multiple dots orbiting around a center point like planets. Elegant spinning effect.

breathingCircle → const LoadingStyle

Circle that smoothly expands and contracts like breathing. Calm and elegant loading indicator.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<LoadingStyle>
A constant List of the values in this enum, in order of their declaration.