BlurredLoadingOverlay class
A widget that displays a blurred loading overlay on top of its child.
When isLoading is true, a blur effect is applied to the background and a loading animation is shown in the center.
Example:
// Using default loading styles
BlurredLoadingOverlay(
isLoading: _isLoading,
child: MyContent(),
loadingStyle: LoadingStyle.bouncingLineCircle,
)
// Using custom loading widget
BlurredLoadingOverlay(
isLoading: _isLoading,
child: MyContent(),
customLoadingWidget: CircularProgressIndicator(),
)
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- BlurredLoadingOverlay
Constructors
- BlurredLoadingOverlay({Key? key, required bool isLoading, required Widget child, LoadingStyle loadingStyle = LoadingStyle.pulseRing, Widget? customLoadingWidget, double blurSigma = 4.0, Color? backgroundColor, Color? loadingColor, double loadingSize = 50.0, Widget? headerWidget, })
-
Creates a blurred loading overlay widget.
const
Properties
- backgroundColor → Color?
-
The background color of the overlay.
final
- blurSigma → double
-
The amount of blur to apply to the background.
final
- child → Widget
-
The widget below this widget in the tree.
final
- customLoadingWidget → Widget?
-
A custom widget to display as the loading indicator.
final
-
An optional widget to display below the loading animation.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- headerWidget → Widget?
-
An optional widget to display above the loading animation.
final
- isLoading → bool
-
Whether to show the loading overlay.
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- loadingColor → Color?
-
The color of the loading animation.
final
- loadingSize → double
-
The size of the loading animation.
final
- loadingStyle → LoadingStyle
-
The style of loading animation to display.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited