BlurredLoadingPercentage class
A widget that displays a blurred loading overlay with progress percentage.
Shows either a line or circular progress indicator with percentage text. When isLoading is true, the overlay is displayed.
Example:
BlurredLoadingPercentage(
isLoading: _isLoading,
child: MyContent(),
progress: 45.5, // 45.5% progress
progressStyle: ProgressStyle.circle,
progressColor: Colors.blue,
)
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- BlurredLoadingPercentage
Constructors
- BlurredLoadingPercentage({Key? key, required bool isLoading, required Widget child, double progress = 0.0, double blurSigma = 4.0, Color? backgroundColor, Color progressColor = Colors.blue, Color? trackColor, double strokeWidth = 8.0, Color textColor = Colors.white, double textSize = 24.0, bool showProgress = true, ProgressStyle progressStyle = ProgressStyle.circle, double size = 120.0, Widget? headerWidget, })
-
Creates a blurred loading percentage widget.
const
Properties
- backgroundColor → Color?
-
The background color of the overlay.
final
- blurSigma → double
-
The amount of blur to apply to the background.
final
- child → Widget
-
The widget below this widget in the tree.
final
-
An optional widget to display below the progress indicator.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- headerWidget → Widget?
-
An optional widget to display above the progress indicator.
final
- isLoading → bool
-
Whether to show the loading overlay.
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- progress → double
-
The progress value from 0.0 to 100.0.
final
- progressColor → Color
-
The color of the progress indicator.
final
- progressStyle → ProgressStyle
-
The style of progress indicator.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showProgress → bool
-
Whether to show the percentage text.
final
- size → double
-
The size of the progress indicator.
final
- strokeWidth → double
-
The width of the stroke.
final
- textColor → Color
-
The color of the progress text.
final
- textSize → double
-
The font size of the progress text.
final
- trackColor → Color?
-
The color of the track behind the progress.
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited